@@ -4,8 +4,12 @@ import codecs
 from glob import glob
 import logging
 import shutil
+from lxml import etree
+from tempfile import mkdtemp, mktemp
 from subprocess import check_output
 
+import networkx as nx
+
 def _sentiter(func):
     return lambda self: [func(self, sent) for sent in self._sents()]
 
